# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: datasync.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='datasync.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0e\x64\x61tasync.proto\" \n\x0f\x44\x61taSyncRequest\x12\r\n\x05value\x18\x01 \x01(\t\"!\n\x10\x44\x61taSyncResponse\x12\r\n\x05value\x18\x01 \x01(\t2=\n\x08\x44\x61taSync\x12\x31\n\x08\x44\x61taSync\x12\x10.DataSyncRequest\x1a\x11.DataSyncResponse\"\x00\x62\x06proto3'
)




_DATASYNCREQUEST = _descriptor.Descriptor(
  name='DataSyncRequest',
  full_name='DataSyncRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='DataSyncRequest.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18,
  serialized_end=50,
)


_DATASYNCRESPONSE = _descriptor.Descriptor(
  name='DataSyncResponse',
  full_name='DataSyncResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='DataSyncResponse.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=52,
  serialized_end=85,
)

DESCRIPTOR.message_types_by_name['DataSyncRequest'] = _DATASYNCREQUEST
DESCRIPTOR.message_types_by_name['DataSyncResponse'] = _DATASYNCRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DataSyncRequest = _reflection.GeneratedProtocolMessageType('DataSyncRequest', (_message.Message,), {
  'DESCRIPTOR' : _DATASYNCREQUEST,
  '__module__' : 'datasync_pb2'
  # @@protoc_insertion_point(class_scope:DataSyncRequest)
  })
_sym_db.RegisterMessage(DataSyncRequest)

DataSyncResponse = _reflection.GeneratedProtocolMessageType('DataSyncResponse', (_message.Message,), {
  'DESCRIPTOR' : _DATASYNCRESPONSE,
  '__module__' : 'datasync_pb2'
  # @@protoc_insertion_point(class_scope:DataSyncResponse)
  })
_sym_db.RegisterMessage(DataSyncResponse)



_DATASYNC = _descriptor.ServiceDescriptor(
  name='DataSync',
  full_name='DataSync',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=87,
  serialized_end=148,
  methods=[
  _descriptor.MethodDescriptor(
    name='DataSync',
    full_name='DataSync.DataSync',
    index=0,
    containing_service=None,
    input_type=_DATASYNCREQUEST,
    output_type=_DATASYNCRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DATASYNC)

DESCRIPTOR.services_by_name['DataSync'] = _DATASYNC

# @@protoc_insertion_point(module_scope)
